exceptiontools.InputSpecificationError
======================================

.. inheritance-diagram:: abjad.tools.exceptiontools.InputSpecificationError.InputSpecificationError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.InputSpecificationError.InputSpecificationError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.InputSpecificationError.InputSpecificationError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.InputSpecificationError.InputSpecificationError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.InputSpecificationError.InputSpecificationError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.InputSpecificationError.InputSpecificationError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.InputSpecificationError.InputSpecificationError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.InputSpecificationError.InputSpecificationError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.InputSpecificationError.InputSpecificationError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.InputSpecificationError.InputSpecificationError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
